package com.zoniot.ccrc.controller.common;


import com.zoniot.ccrc.commom.model.AjaxMessage;
import com.zoniot.ccrc.commom.model.Pagination;
import com.zoniot.ccrc.commom.model.ResultStatus;
import com.zoniot.ccrc.entity.Message;
import com.zoniot.ccrc.service.MessageService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Controller
@ResponseBody
@RequestMapping("message")
@Api(tags = "消息")
public class MessageController {

    @Autowired
    private MessageService messageService;

    @GetMapping("/getMessagePage")
    @ApiOperation(value = "获取消息分页")
    public AjaxMessage<Pagination<Message>> getMessageList(
            @ApiParam(value = "是否已读 0：未读 1：已读", required = false) @RequestParam(required = false) Integer read,
            @ApiParam(value = "页数,非必传，默认第一页", required = false, defaultValue = "1") @RequestParam(required = false, defaultValue = "1") int pageNum,
            @ApiParam(value = "条数，非必传，默认15条", required = false, defaultValue = "15") @RequestParam(required = false, defaultValue = "15") int pageSize
    ) {
        Pagination<Message> list = messageService.getMessageList(read,pageNum, pageSize);
        return new AjaxMessage<>(ResultStatus.OK, list);
    }

    @GetMapping("/getMessageCount")
    @ApiOperation(value = "获取消息数量")
    public AjaxMessage getMessageCount(
    ) {
        Integer result = messageService.getMessageCount();
        return new AjaxMessage<>(ResultStatus.OK, result);
    }

    @DeleteMapping("/delMessage")
    @ApiOperation(value = "获取消息数量")
    public AjaxMessage delMessage(
            @ApiParam(value = "id,多个英文逗号隔开", required = true) @RequestParam(required = true) List<Integer> ids
    ) {
        messageService.delMessage(ids);
        return new AjaxMessage<>(ResultStatus.OK);
    }

    @PostMapping("/markRead")
    @ApiOperation(value = "标记已读")
    public AjaxMessage markRead(
            @ApiParam(value = "id,多个英文逗号隔开", required = true) @RequestParam(required = true) List<Integer> ids
    ) {
        messageService.markRead(ids);
        return new AjaxMessage<>(ResultStatus.OK);
    }
}
