package com.zoniot.ccrc.controller.system;


import com.zoniot.ccrc.commom.model.AjaxMessage;
import com.zoniot.ccrc.commom.model.Pagination;
import com.zoniot.ccrc.commom.model.ResultStatus;
import com.zoniot.ccrc.entity.OperationLog;
import com.zoniot.ccrc.service.OperationLogService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.time.LocalDateTime;

@Controller
@RequestMapping("system/operationLog")
@Api(tags = "操作日志")
public class OperationLogController {
    @Autowired
    private OperationLogService operationLogService;

    @ResponseBody
    @GetMapping("getPage")
    @ApiOperation(value = "查询操作日志分页")
    public AjaxMessage<Pagination<OperationLog>> getPage(
            @ApiParam(value = "用户名", required = false) @RequestParam(required = false) String username,
            @ApiParam(value = "操作内容", required = false) @RequestParam(required = false) String content,
            @ApiParam(value = "手机号", required = false) @RequestParam(required = false) String mobilephone,
            @ApiParam(value = "开始时间 格式：yyyyMMddHHmmss", required = false) @RequestParam(required = false) @DateTimeFormat(pattern = "yyyyMMddHHmmss") LocalDateTime startDate,
            @ApiParam(value = "开始时间 格式：yyyyMMddHHmmss", required = false) @RequestParam(required = false) @DateTimeFormat(pattern = "yyyyMMddHHmmss") LocalDateTime endDate,
            @ApiParam(value = "页数,非必传，默认第一页", required = false, defaultValue = "1") @RequestParam(required = false, defaultValue = "1") int pageNum,
            @ApiParam(value = "条数，非必传，默认15条", required = false, defaultValue = "15") @RequestParam(required = false, defaultValue = "15") int pageSize
    ){
        Pagination<OperationLog> pageInfo = operationLogService.getPage(username,content, startDate, endDate, pageNum, pageSize,mobilephone);
        return new AjaxMessage<>(ResultStatus.OK, pageInfo);
    }

    @ResponseBody
    @PostMapping("add")
    @ApiOperation(value = "添加操作日志")
    public AjaxMessage add(
            @ApiParam(value = "操作日志", required = true) @RequestBody(required = true)  OperationLog operationLog
    ) {
        operationLogService.add(operationLog);
        return new AjaxMessage(ResultStatus.OK);
    }

    @GetMapping("/getExcel")
    @ApiOperation(value = "操作日志导出excel")
    public void getExcel(
            @ApiParam(value = "用户名", required = false) @RequestParam(required = false) String username,
            @ApiParam(value = "操作内容", required = false) @RequestParam(required = false) String content,
            @ApiParam(value = "手机号码", required = false) @RequestParam(required = false) String mobilephone,
            @ApiParam(value = "开始时间 格式：yyyyMMddHHmmss", required = false) @RequestParam(required = false) @DateTimeFormat(pattern = "yyyyMMddHHmmss") LocalDateTime startDate,
            @ApiParam(value = "开始时间 格式：yyyyMMddHHmmss", required = false) @RequestParam(required = false) @DateTimeFormat(pattern = "yyyyMMddHHmmss") LocalDateTime endDate,
            HttpServletResponse httpServletResponse
    ) {
        operationLogService.getExcel(username,content, startDate, endDate, mobilephone, httpServletResponse);
    }
}
