package com.zoniot.ccrc.scheduled;



import com.zoniot.ccrc.commom.utils.SendWechatPush;
import com.zoniot.ccrc.dao.*;
import com.zoniot.ccrc.entity.*;
import com.zoniot.ccrc.service.AccessTokenService;
import com.zoniot.ccrc.service.MongoMeterReadRecordService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Date;
import java.util.List;

@Slf4j
@Component
@Configuration
@EnableScheduling
public class WarningMessageJob {


    @Resource
    private WarningRuleMapper warningRuleMapper;
    @Resource
    private WarningLogMapper warningLogMapper;
    @Resource
    private WarningMessageMapper warningMessageMapper;
    @Autowired
    private MongoMeterReadRecordService mongoMeterReadRecordService;
    @Resource
    private DeviceMapper deviceMapper;
    @Resource
    private GridManagementMapper gridManagementMapper;
    @Autowired
    private AccessTokenService accessTokenService;
    @Resource
    private UserMapper userMapper;

    @Value("${wechat.oa.appid}")
    private String oaAppid;

    @Value("${wechat.mp.appid}")
    private String mpAppid;


    /**
     * 每天预警消息
     */
    @Scheduled(cron = "0 0 10 * * ?")
    public void warningMessage() {
        log.info("begin warningMessage job");
        List<WarningRule> list = warningRuleMapper.getList(null);
        if (list != null && list.size() > 0) {
            for (WarningRule warningRule : list) {
                    Boolean flag =  mongoMeterReadRecordService.complyWithWarningRules(warningRule.getDeviceId(),warningRule.getWarningType());
                    if ( flag) {
                        String content ="";
                        if(warningRule.getWarningType()==4){
                            content =  "单日用水量超过2吨";
                        }else if(warningRule.getWarningType()==3){
                            content =  "单日用水量少于0.01吨";
                        }

                        addMessageInfo(warningRule,content);
                        sendWechatMessage(warningRule.getDeviceId(),content);
                }


            }
        }
        log.info("end warningMessage job");
    }
    private void addMessageInfo(WarningRule warningRule,String content){
        WarningLog warningLogNew = new WarningLog();

        warningLogNew.setDeviceId(warningRule.getDeviceId());
        warningLogNew.setWarningType(warningRule.getWarningType());
        warningLogNew.setFeedbackStatus(0);
        warningLogNew.setFeedbackContent("");
        //warningLogNew.setLastDate(LocalDateTime.now());
        warningLogNew.setStatus(1);
        warningLogNew.setCreateBy("system");
        warningLogNew.setDateCreate(LocalDateTime.now());
        warningLogNew.setUpdateBy("system");
        warningLogNew.setDateUpdate(LocalDateTime.now());
        warningLogMapper.insertSelective(warningLogNew);

        WarningMessage warningMessageNew = new WarningMessage();
        warningMessageNew.setWarningLogId(warningLogNew.getId());
        warningMessageNew.setContent(content);
        warningMessageNew.setStatus(1);
        warningMessageNew.setCreateBy("system");
        warningMessageNew.setDateCreate(LocalDateTime.now());
        warningMessageNew.setUpdateBy("system");
        warningMessageNew.setDateUpdate(LocalDateTime.now());
        warningMessageMapper.insertSelective(warningMessageNew);
    }

    private void sendWechatMessage(Long deviceId,String content){
        DateTimeFormatter df = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
        String url = "https://www.zoniot.com";
        String pagepath = "pages/index/index";
        Device device = deviceMapper.findByDeviceId(deviceId);

        String accessToken = accessTokenService.getMpAccessToken();

        List<GridManagement> gridManagementList = gridManagementMapper.getByDeviceId(deviceId);
        if (gridManagementList != null && gridManagementList.size() > 0) {
            for (GridManagement gridManagement : gridManagementList) {
                User user = userMapper.findUserById(gridManagement.getUserId());

                if(user != null && user.getOpenid() !=null && !"".equals(user.getOpenid())){

                    String result = SendWechatPush.sendAbnormalNotice(accessToken, oaAppid, user.getOpenid(), url, mpAppid, pagepath, "用户用水异常", "水量预警", content,
                            LocalDateTime.now().format(df), device.getMeterNo()+gridManagement.getCustomerName()+gridManagement.getCustomerPhone()+device.getLocDesc()+"用水量有异常情况，请及时关注用户情况！");
                    log.info("sendWechatMessage :"+result);
                }
            }
        }



    }
}
